@@ -31,18 +31,21 @@
 setGeneric("readNamedRegion",
 	function(object, name, header = TRUE, rownames = NULL, colTypes = character(0),
 			forceConversion = FALSE, dateTimeFormat = getOption("XLConnect.dateTimeFormat"),
-			check.names = TRUE, useCachedValues = FALSE, keep=NULL, drop=NULL) standardGeneric("readNamedRegion"))
+			check.names = TRUE, useCachedValues = FALSE, keep = NULL, drop = NULL, simplify = FALSE,
+      readStrategy = "default") 
+    standardGeneric("readNamedRegion"))
 
 
 setMethod("readNamedRegion", 
 	signature(object = "workbook"), 
 	function(object, name, header = TRUE, rownames = NULL, colTypes = character(0),
 			forceConversion = FALSE, dateTimeFormat = getOption("XLConnect.dateTimeFormat"),
-			check.names = TRUE, useCachedValues = FALSE, keep=NULL, drop=NULL) {
+			check.names = TRUE, useCachedValues = FALSE, keep = NULL, drop = NULL, simplify = FALSE,
+      readStrategy = "default") {
 
 		# returns a list of RDataFrameWrapper Java object references
 		sheet = as.vector(extractSheetName(getReferenceFormula(object, name)))
-		namedim = matrix(as.vector(t(getReferenceCoordinates(object, name))), nrow=4, byrow=FALSE)
+		namedim = matrix(as.vector(t(getReferenceCoordinatesForName(object, name))), nrow=4, byrow=FALSE)
 		startRow = namedim[1,]
 		startCol = namedim[2,]
 		endRow = namedim[3,]
@@ -51,7 +54,7 @@ setMethod("readNamedRegion",
 
 		subset <- getColSubset(object, sheet, startRow, endRow, startCol, endCol, header, numcols, keep, drop)
 		dataFrame <- xlcCall(object, "readNamedRegion", name, header, .jarray(classToXlcType(colTypes)), 
-				forceConversion, dateTimeFormat, useCachedValues, subset, SIMPLIFY = FALSE)
+				forceConversion, dateTimeFormat, useCachedValues, subset, readStrategy, SIMPLIFY = FALSE)
 		
 
     # get data.frames from Java
@@ -59,6 +62,15 @@ setMethod("readNamedRegion",
 		# extract rownames
     dataFrame = extractRownames(dataFrame, rownames)
 		names(dataFrame) <- name
+    
+    # simplify
+    dataFrame =
+    mapply(df = dataFrame, simplify = rep(simplify, length.out = length(dataFrame)), 
+           FUN = function(df, simplify) {
+             if(simplify) unlist(df, use.names = FALSE)
+             else df
+          }, SIMPLIFY = FALSE
+    )
 		
 		# Return data.frame directly in case only one data.frame is read
 		if(length(dataFrame) == 1) dataFrame[[1]]
